==> haskell-store-core-0.4.4.7-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-HILDpY6eG7rF9YBtzhHWnx
key:                  store-core-0.4.4.7-HILDpY6eG7rF9YBtzhHWnx
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  a9fbb59ae21a914ccfabc79ac3f0115b
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-HILDpY6eG7rF9YBtzhHWnx
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.9.1.0-LKIwDdhUWCeBBmo7dhK3va text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-core-0.4.4.7-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-4viCHC3svLHKN3toAlXYYK
key:                  store-core-0.4.4.7-4viCHC3svLHKN3toAlXYYK
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  3b67d304c7ea9baf582293a7f92e04a5
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-4viCHC3svLHKN3toAlXYYK
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.9.1.0-8nzcMUtKW4yAfvV7oeRfvP text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
